@@ -441,53 +441,54 @@ void Engine::read(std::string& str) THROWS (PersistException)
 #define CCXX_RE(ar,ob)   ar.read(ob); return ar
 #define CCXX_WE(ar,ob)   ar.write(ob); return ar
 
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, BaseObject &ob) THROWS (PersistException) {CCXX_RE(ar,ob);}
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, BaseObject *&ob) THROWS (PersistException) {CCXX_RE(ar,ob);}
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, BaseObject const &ob) THROWS (PersistException) {CCXX_WE(ar,&ob);}
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, BaseObject const *ob) THROWS (PersistException) {CCXX_WE(ar,ob);}
+Engine& operator >>( Engine& ar, BaseObject &ob) THROWS (PersistException) {CCXX_RE(ar,ob);}
+Engine& operator >>( Engine& ar, BaseObject *&ob) THROWS (PersistException) {CCXX_RE(ar,ob);}
+Engine& operator <<( Engine& ar, BaseObject const &ob) THROWS (PersistException) {CCXX_WE(ar,&ob);}
+Engine& operator <<( Engine& ar, BaseObject const *ob) THROWS (PersistException) {CCXX_WE(ar,ob);}
 
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, int8& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, int8 ob) THROWS (PersistException) {CCXX_WE (ar,ob);}
+Engine& operator >>( Engine& ar, int8& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
+Engine& operator <<( Engine& ar, int8 ob) THROWS (PersistException) {CCXX_WE (ar,ob);}
 
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, uint8& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, uint8 ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
+Engine& operator >>( Engine& ar, uint8& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
+Engine& operator <<( Engine& ar, uint8 ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
 
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, int16& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, int16 ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
+Engine& operator >>( Engine& ar, int16& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
+Engine& operator <<( Engine& ar, int16 ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
 
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, uint16& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, uint16 ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
+Engine& operator >>( Engine& ar, uint16& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
+Engine& operator <<( Engine& ar, uint16 ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
 
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, int32& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, int32 ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
+Engine& operator >>( Engine& ar, int32& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
+Engine& operator <<( Engine& ar, int32 ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
 
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, uint32& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, uint32 ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
+Engine& operator >>( Engine& ar, uint32& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
+Engine& operator <<( Engine& ar, uint32 ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
 
 #ifdef  HAVE_64_BITS
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, int64& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, int64 ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
+Engine& operator >>( Engine& ar, int64& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
+Engine& operator <<( Engine& ar, int64 ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
 
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, uint64& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, uint64 ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
+Engine& operator >>( Engine& ar, uint64& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
+Engine& operator <<( Engine& ar, uint64 ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
 #endif
 
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, float& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, float ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
+Engine& operator >>( Engine& ar, float& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
+Engine& operator <<( Engine& ar, float ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
 
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, double& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, double ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
+Engine& operator >>( Engine& ar, double& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
+Engine& operator <<( Engine& ar, double ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
 
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, String& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, String ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
+Engine& operator >>( Engine& ar, String& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
+Engine& operator <<( Engine& ar, String ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
 
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, std::string& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, std::string ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
+Engine& operator >>( Engine& ar, std::string& ob) THROWS (PersistException) {CCXX_RE (ar,ob);}
+Engine& operator <<( Engine& ar, std::string ob)  THROWS (PersistException) {CCXX_WE (ar,ob);}
 
-CCXX_EXPORT(Engine&) operator >>( Engine& ar, bool& ob) THROWS (PersistException) {
+Engine& operator >>( Engine& ar, bool& ob) THROWS (PersistException) {
   uint32 a; ar.read(a); ob=a==1;return ar;
 }
-CCXX_EXPORT(Engine&) operator <<( Engine& ar, bool ob) THROWS (PersistException) {
+
+Engine& operator <<( Engine& ar, bool ob) THROWS (PersistException) {
   uint32 a=ob?1:0; ar.write(a); return ar;
 }
 
