@@ -455,7 +455,7 @@ ssize_t Socket::writeData(const void *Source, size_t Size, timeout_t timeout)
             return (-1);
           }
 
-      nstat =::send (so, Slide, _IOLEN64 Size, 0);
+      nstat =::send (so, Slide, _IOLEN64 Size, MSG_NOSIGNAL);
 
       if (nstat <= 0)
         {
@@ -1546,7 +1546,7 @@ ssize_t UDPSocket::send(const void *buf, size_t len)
 		alen = 0;
 	}
 	
-	return _IORET64 ::sendto(so, (const char *)buf, _IOLEN64 len, 0, addr, alen);
+	return _IORET64 ::sendto(so, (const char *)buf, _IOLEN64 len, MSG_NOSIGNAL, addr, alen);
 }
 
 ssize_t UDPSocket::receive(void *buf, size_t len, bool reply)
@@ -3105,7 +3105,7 @@ size_t TCPStream::printf(const char *format, ...)
 	if(Socket::state == STREAM)
 		return ::write((int)so, buf, _IOLEN64 len);
 	else
-		return ::send(so, buf, _IOLEN64 len, 0);
+		return ::send(so, buf, _IOLEN64 len, MSG_NOSIGNAL);
 }
 #endif
 
@@ -3123,7 +3123,7 @@ int TCPStream::overflow(int c)
 		if(Socket::state == STREAM)
 			rlen = ::write((int)so, (const char *)&ch, 1);
 		else
-			rlen = ::send(so, (const char *)&ch, 1, 0);
+			rlen = ::send(so, (const char *)&ch, 1, MSG_NOSIGNAL);
 		if(rlen < 1)
 		{
 			if(rlen < 0)
@@ -3146,7 +3146,7 @@ int TCPStream::overflow(int c)
 		if(Socket::state == STREAM)
 			rlen = ::write((int)so, (const char *)pbase(), req);
 		else
-			rlen = ::send(so, (const char *)pbase(), req, 0);
+			rlen = ::send(so, (const char *)pbase(), req, MSG_NOSIGNAL);
 		if(rlen < 1)
 		{
 			if(rlen < 0)
