@@ -893,7 +893,6 @@ int Thread::detach(Semaphore *st)
 		_start->post();
 	return 0;
 #else
-	int rtn;
 	if(!priv)
 		return -1;
 
@@ -912,8 +911,7 @@ int Thread::detach(Semaphore *st)
 	pthread_attr_setdetachstate(&priv->_attr, PTHREAD_CREATE_DETACHED);
 
 	_start = st;
-	rtn = pthread_create(&priv->_tid, &priv->_attr, exec_t(&ccxx_exec_handler), this);
-	if(!rtn && priv->_tid)
+	if(!pthread_create(&priv->_tid, &priv->_attr, exec_t(&ccxx_exec_handler), this))
 		return 0;
 	return -1;
 #endif
