@@ -67,14 +67,14 @@ using namespace std;
 static const unsigned char alphabet[65] = 
 	"ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/";
 
-CCXX_EXPORT(char*) b64Encode(const char *source, char *dest, size_t limit)
+char* b64Encode(const char *source, char *dest, size_t limit)
 {
 	b64Encode((const unsigned char*)source,strlen(source),
 			dest,limit);
 	return dest;
 }
 
-CCXX_EXPORT(char*) b64Decode(char *source, char *dest)
+char* b64Decode(char *source, char *dest)
 {
 	size_t srcsize = strlen(source);
 	char* dst = dest?dest:source;
@@ -84,7 +84,7 @@ CCXX_EXPORT(char*) b64Decode(char *source, char *dest)
 	return dst;
 }
 
-CCXX_EXPORT(size_t) b64Encode(const unsigned char *src, size_t srcsize,
+size_t b64Encode(const unsigned char *src, size_t srcsize,
 		               char *dst, size_t dstsize)
 {
 	if (!dstsize) return 0;
@@ -125,7 +125,7 @@ CCXX_EXPORT(size_t) b64Encode(const unsigned char *src, size_t srcsize,
 	return pdst-dst;
 }
 
-CCXX_EXPORT(size_t) b64Decode(const char *src,
+size_t b64Decode(const char *src,
 		unsigned char *dst, size_t dstsize)
 {
         char decoder[256];
@@ -174,7 +174,7 @@ CCXX_EXPORT(size_t) b64Decode(const char *src,
 }
 
 
-CCXX_EXPORT(char*) urlDecode(char *source, char *dest)
+char* urlDecode(char *source, char *dest)
 {
 	char *ret;
 	char hex[3];
@@ -225,7 +225,7 @@ CCXX_EXPORT(char*) urlDecode(char *source, char *dest)
 	return ret;
 }	
 
-CCXX_EXPORT(char*) urlEncode(const char *source, char *dest, size_t max)	
+char* urlEncode(const char *source, char *dest, size_t max)	
 {
 	static const char *hex = "0123456789abcdef";
 	size_t len = 0;
@@ -263,7 +263,7 @@ CCXX_EXPORT(char*) urlEncode(const char *source, char *dest, size_t max)
  * @return base 64 encoded string
  * @param src source string
  */
-CCXX_EXPORT(String) b64Encode(const String& src)
+String b64Encode(const String& src)
 {
   size_t limit = (src.length()+2)/3*4+1;  // size + null must be included
   char buffer[limit];
@@ -281,7 +281,7 @@ CCXX_EXPORT(String) b64Encode(const String& src)
  * @return decoded string
  * @param src     source string
  */
-CCXX_EXPORT(String) b64Decode(const String& src)
+String b64Decode(const String& src)
 {
   size_t limit = src.length()/4*3;
   unsigned char buffer[limit+1];
@@ -298,7 +298,7 @@ CCXX_EXPORT(String) b64Decode(const String& src)
  * @param src     source buffer
  * @param srcsize source buffer size
  */
-CCXX_EXPORT(String) b64Encode(const unsigned char *src, size_t srcsize)
+String b64Encode(const unsigned char *src, size_t srcsize)
 {
   size_t limit = (srcsize+2)/3*4+1;
   char buffer[limit];
@@ -318,7 +318,7 @@ CCXX_EXPORT(String) b64Encode(const unsigned char *src, size_t srcsize)
  * @param dst     destination octet buffer
  * @param dstsize destination buffer size
  */
-CCXX_EXPORT(size_t) b64Decode(const String& src,
+size_t b64Decode(const String& src,
   unsigned char *dst, size_t dstsize)
 {
   return b64Decode(src.c_str(), dst, dstsize);
